// This work is licensed under the Creative Commons Attribution-ShareAlike 3.0 Unported License.
// To view a copy of this license, visit http://creativecommons.org/licenses/by-sa/3.0/ or send a
// letter to Creative Commons, 444 Castro Street, Suite 900, Mountain View, California, 94041, USA.

// Persistence of Vision Ray Tracer version 3.7 include file
// File: colors_srgb.inc
// Author: Richard Callwood III
// Description: This file redefines the named colors from colors.inc,
//   interpreting them as sRGB, regardless of the scene's assumed_gamma.
//   The redefined colors will render to the appearance they had in pre-3.7
//   scenes that omitted assumed_gamma.  Some additional international
//   spellings are also defined.
//
//   This file is intended only to complement colors.inc, not replace it.
//
//   Important: assumed_gamma MUST be set in global_settings before including
//   this file.
//
// Copyright © 2016 Richard Callwood III.  Some rights reserved (see above).
//
// History:
//   2016-Mar-23  Created.
#ifndef (Colors_sRGB_Inc_Temp)

#declare Colors_sRGB_Inc_Temp = version;
#version 3.7;

#ifdef (View_POV_Include_Stack)
  #debug "including colors_srgb.inc\n"
#end

#include "colors.inc"

// COLORS:
//  The first 9 colors are omitted, as they do not vary with gamma.

// PERCENTAGE GRAYS:
#declare Gray05 = srgbft Gray05;
#declare Gray10 = srgbft Gray10;
#declare Gray15 = srgbft Gray15;
#declare Gray20 = srgbft Gray20;
#declare Gray25 = srgbft Gray25;
#declare Gray30 = srgbft Gray30;
#declare Gray35 = srgbft Gray35;
#declare Gray40 = srgbft Gray40;
#declare Gray45 = srgbft Gray45;
#declare Gray50 = srgbft Gray50;
#declare Gray55 = srgbft Gray55;
#declare Gray60 = srgbft Gray60;
#declare Gray65 = srgbft Gray65;
#declare Gray70 = srgbft Gray70;
#declare Gray75 = srgbft Gray75;
#declare Gray80 = srgbft Gray80;
#declare Gray85 = srgbft Gray85;
#declare Gray90 = srgbft Gray90;
#declare Gray95 = srgbft Gray95;

// OTHER GRAYS:
#declare DimGray = srgbft DimGray;
#declare DimGrey = srgbft DimGrey;
#declare Gray = srgbft Gray;
#declare Grey = srgbft Grey;
#declare LightGray = srgbft LightGray;
#declare LightGrey = srgbft LightGrey;
#declare VLightGray = srgbft VLightGray;
#declare VLightGrey = srgbft VLightGrey;

// OTHER COLORS:
#declare Aquamarine = srgbft Aquamarine;
#declare BlueViolet = srgbft BlueViolet;
#declare Brown = srgbft Brown;
#declare CadetBlue = srgbft CadetBlue;
#declare Coral = srgbft Coral;
#declare CornflowerBlue = srgbft CornflowerBlue;
#declare DarkGreen = srgbft DarkGreen;
#declare DarkOliveGreen = srgbft DarkOliveGreen;
#declare DarkOrchid = srgbft DarkOrchid;
#declare DarkSlateBlue = srgbft DarkSlateBlue;
#declare DarkSlateGray = srgbft DarkSlateGray;
#declare DarkSlateGrey = srgbft DarkSlateGrey;
#declare DarkTurquoise = srgbft DarkTurquoise;
#declare Firebrick = srgbft Firebrick;
#declare ForestGreen = srgbft ForestGreen;
#declare Gold = srgbft Gold;
#declare Goldenrod = srgbft Goldenrod;
#declare GreenYellow = srgbft GreenYellow;
#declare IndianRed = srgbft IndianRed;
#declare Khaki = srgbft Khaki;
#declare LightBlue = srgbft LightBlue;
#declare LightSteelBlue = srgbft LightSteelBlue;
#declare LimeGreen = srgbft LimeGreen;
#declare Maroon = srgbft Maroon;
#declare MediumAquamarine = srgbft MediumAquamarine;
#declare MediumBlue = srgbft MediumBlue;
#declare MediumForestGreen = srgbft MediumForestGreen;
#declare MediumGoldenrod = srgbft MediumGoldenrod;
#declare MediumOrchid = srgbft MediumOrchid;
#declare MediumSeaGreen = srgbft MediumSeaGreen;
#declare MediumSlateBlue = srgbft MediumSlateBlue;
#declare MediumSpringGreen = srgbft MediumSpringGreen;
#declare MediumTurquoise = srgbft MediumTurquoise;
#declare MediumVioletRed = srgbft MediumVioletRed;
#declare MidnightBlue = srgbft MidnightBlue;
#declare Navy = srgbft Navy;
#declare NavyBlue = srgbft NavyBlue;
#declare Orange = srgbft Orange;
#declare OrangeRed = srgbft OrangeRed;
#declare Orchid = srgbft Orchid;
#declare PaleGreen = srgbft PaleGreen;
#declare Pink = srgbft Pink;
#declare Plum = srgbft Plum;
#declare Salmon = srgbft Salmon;
#declare SeaGreen = srgbft SeaGreen;
#declare Sienna = srgbft Sienna;
#declare SkyBlue = srgbft SkyBlue;
#declare SlateBlue = srgbft SlateBlue;
#declare SpringGreen = srgbft SpringGreen;
#declare SteelBlue = srgbft SteelBlue;
#declare Tan = srgbft Tan;
#declare Thistle = srgbft Thistle;
#declare Turquoise = srgbft Turquoise;
#declare Violet = srgbft Violet;
#declare VioletRed = srgbft VioletRed;
#declare Wheat = srgbft Wheat;
#declare YellowGreen = srgbft YellowGreen;
#declare SummerSky = srgbft SummerSky;
#declare RichBlue = srgbft RichBlue;
#declare Brass = srgbft Brass;
#declare Copper = srgbft Copper;
#declare Bronze = srgbft Bronze;
#declare Bronze2 = srgbft Bronze2;
#declare Silver = srgbft Silver;
#declare BrightGold = srgbft BrightGold;
#declare OldGold = srgbft OldGold;
#declare Feldspar = srgbft Feldspar;
#declare Quartz = srgbft Quartz;
#declare Mica = srgbft Mica;
#declare NeonPink = srgbft NeonPink;
#declare DarkPurple = srgbft DarkPurple;
#declare NeonBlue = srgbft NeonBlue;
#declare CoolCopper = srgbft CoolCopper;
#declare MandarinOrange = srgbft MandarinOrange;
#declare LightWood = srgbft LightWood;
#declare MediumWood = srgbft MediumWood;
#declare DarkWood = srgbft DarkWood;
#declare SpicyPink = srgbft SpicyPink;
#declare SemiSweetChoc = srgbft SemiSweetChoc;
#declare BakersChoc = srgbft BakersChoc;
#declare Flesh = srgbft Flesh;
#declare NewTan = srgbft NewTan;
#declare NewMidnightBlue = srgbft NewMidnightBlue;
#declare VeryDarkBrown = srgbft VeryDarkBrown;
#declare DarkBrown = srgbft DarkBrown;
#declare DarkTan = srgbft DarkTan;
#declare GreenCopper = srgbft GreenCopper;
#declare DkGreenCopper = srgbft DkGreenCopper;
#declare DustyRose = srgbft DustyRose;
#declare HuntersGreen = srgbft HuntersGreen;
#declare Scarlet = srgbft Scarlet;
#declare Med_Purple = srgbft Med_Purple;
#declare Light_Purple = srgbft Light_Purple;
#declare Very_Light_Purple = srgbft Very_Light_Purple;

// INTERNATIONAL SPELLINGS (not declared in colors.inc):
#declare Grey05 = Gray05;
#declare Grey10 = Gray10;
#declare Grey15 = Gray15;
#declare Grey20 = Gray20;
#declare Grey25 = Gray25;
#declare Grey30 = Gray30;
#declare Grey35 = Gray35;
#declare Grey40 = Gray40;
#declare Grey45 = Gray45;
#declare Grey50 = Gray50;
#declare Grey55 = Gray55;
#declare Grey60 = Gray60;
#declare Grey65 = Gray65;
#declare Grey70 = Gray70;
#declare Grey75 = Gray75;
#declare Grey80 = Gray80;
#declare Grey85 = Gray85;
#declare Grey90 = Gray90;
#declare Grey95 = Gray95;

#version Colors_sRGB_Inc_Temp;
#end
